==> nextcloud-31.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Cloud Fédéré incorrect",
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "Couldn't establish a federated share." : "Impossible d'établir un partage fédéré.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossible d’établir un partage fédéré, peut-être que le mot de passe est incorrect.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Demande de partage fédéré envoyée, vous allez recevoir une invitation. Vérifiez vos notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossible d'établir un partage fédére, il semble que le serveur avec lequel fédérer est trop vieux (Nextcloud <=9)",
    "It is not allowed to send federated group shares from this server." : "Il n'est pas autorisé d'envoyer des partages à des groupes fédérés depuis ce serveur.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Impossible de partager %1$s car il est déjà partagé avec le compte %2$s",
    "Not allowed to create a federated share to the same account" : "Non autorisé à créer un partage fédéré vers le même compte",
    "Federated shares require read permissions" : "Les partages fédérés nécessitent des permissions de lecture.",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %1$s a échoué, impossible de trouver %2$s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
    "Could not find share" : "Impossible de trouver le partage",
    "Federated sharing" : "Partage fédéré",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vous avez reçu {share} comme partage distant de la part de {user} (de la part de {behalf})",
    "You received {share} as a remote share from {user}" : "Vous avez reçu {share} comme partage distant de la part de {user}",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Federated Cloud Sharing" : "Partage Cloud Fédéré",
    "Sharing" : "Partage",
    "Federated file sharing" : "Partage de fichiers fédéré",
    "Provide federated file sharing across servers" : "Fourni un partage de fichiers fédéré entre plusieurs serveurs",
    "Disable upload" : "Désactiver le téléchargement",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "De plus, les adresses mail des utilisateurs peuvent être envoyées à ce système pour les vérifier.",
    "Unable to update federated files sharing config" : "Impossible de mettre à jour la configuration du partage fédéré de fichiers ",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre personnes de ce serveur s'ils utilisent des partages fédérés.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les personnes de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
    "Allow people on this server to receive shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages d'autres serveurs",
    "Allow people on this server to send shares to groups on other servers" : "Autoriser les personnes de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
    "Allow people on this server to receive group shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages de groupe d'autres serveurs",
    "Search global and public address book for people" : "Rechercher dans le carnet d'adresses global et public pour les personnes",
    "Allow people to publish their data to a global and public address book" : "Autoriser les personnes à publier leurs données dans un carnet d'adresses global et public",
    "Trusted federation" : "Fédération de confiance",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Accepter par défaut automatiquement les partages provenant de comptes et de groupes fédérés de confiance",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud, voir {url}.",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de Cloud Fédéré copié dans le presse-papiers",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "Clipboard not available. Please copy the cloud ID manually." : "Presse-papiers non disponible. Veuillez copier l'ID cloud manuellement.",
    "Copied!" : "Copié !",
    "Federated Cloud" : "Cloud Fédéré",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son ID de Cloud Fédéré sur une instance fédérée dans la boîte de dialogue de partage. Cela ressemble à utilisateur@cloud.exemple.com.",
    "Your Federated Cloud ID" : "Votre ID de cloud fédéré",
    "Share it so your friends can share files with you:" : "Partagez-le afin que vos amis puissent partager des fichiers avec vous :",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anciennement Twitter)",
    "formerly Twitter" : "anciennement Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
    "HTML Code:" : "Code HTML :",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "Remote share" : "Partage distant",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} depuis {owner}@{remote} ?",
    "Remote share password" : "Mot de passe du partage distant",
    "Incoming share could not be processed" : "Le partage entrant n'a pas pu être traité"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Cloud Fédéré incorrect",
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "Couldn't establish a federated share." : "Impossible d'établir un partage fédéré.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossible d’établir un partage fédéré, peut-être que le mot de passe est incorrect.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Demande de partage fédéré envoyée, vous allez recevoir une invitation. Vérifiez vos notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossible d'établir un partage fédére, il semble que le serveur avec lequel fédérer est trop vieux (Nextcloud <=9)",
    "It is not allowed to send federated group shares from this server." : "Il n'est pas autorisé d'envoyer des partages à des groupes fédérés depuis ce serveur.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Impossible de partager %1$s car il est déjà partagé avec le compte %2$s",
    "Not allowed to create a federated share to the same account" : "Non autorisé à créer un partage fédéré vers le même compte",
    "Federated shares require read permissions" : "Les partages fédérés nécessitent des permissions de lecture.",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %1$s a échoué, impossible de trouver %2$s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
    "Could not find share" : "Impossible de trouver le partage",
    "Federated sharing" : "Partage fédéré",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vous avez reçu {share} comme partage distant de la part de {user} (de la part de {behalf})",
    "You received {share} as a remote share from {user}" : "Vous avez reçu {share} comme partage distant de la part de {user}",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Federated Cloud Sharing" : "Partage Cloud Fédéré",
    "Sharing" : "Partage",
    "Federated file sharing" : "Partage de fichiers fédéré",
    "Provide federated file sharing across servers" : "Fourni un partage de fichiers fédéré entre plusieurs serveurs",
    "Confirm data upload to lookup server" : "Confirmer le téléversement des données sur le serveur de recherche",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Lorsque cette option est activée, toutes les propriétés du compte (par exemple, l'adresse e-mail) dont la visibilité est définie sur \"published\" seront automatiquement synchronisées et transmises à un système externe et mises à disposition dans un carnet d'adresses public et global.",
    "Enable data upload" : "Activer l'envoi de données",
    "Disable upload" : "Désactiver le téléchargement",
    "Confirm querying lookup server" : "Confirmer l'interrogation du serveur de recherche",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Lorsque cette option est activée, la saisie de recherche lors de la création de partages sera envoyée à un système externe qui fournit un carnet d'adresses public et global.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Ceci est utilisé pour récupérer l'ID du cloud fédéré afin de faciliter le partage fédéré.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "De plus, les adresses mail des utilisateurs peuvent être envoyées à ce système pour les vérifier.",
    "Enable querying" : "Activer le requêtage",
    "Disable querying" : "Désactiver le requêtage",
    "Unable to update federated files sharing config" : "Impossible de mettre à jour la configuration du partage fédéré de fichiers ",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre personnes de ce serveur s'ils utilisent des partages fédérés.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les personnes de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
    "Allow people on this server to receive shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages d'autres serveurs",
    "Allow people on this server to send shares to groups on other servers" : "Autoriser les personnes de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
    "Allow people on this server to receive group shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages de groupe d'autres serveurs",
    "The lookup server is only available for global scale." : "Le serveur de recherche n'est disponible que globalement.",
    "Search global and public address book for people" : "Rechercher dans le carnet d'adresses global et public pour les personnes",
    "Allow people to publish their data to a global and public address book" : "Autoriser les personnes à publier leurs données dans un carnet d'adresses global et public",
    "Trusted federation" : "Fédération de confiance",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Accepter par défaut automatiquement les partages provenant de comptes et de groupes fédérés de confiance",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud, voir {url}.",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud",
    "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
    "Cloud ID copied" : "ID de Cloud copié",
    "Copy" : "Copier",
    "Clipboard not available. Please copy the cloud ID manually." : "Presse-papiers non disponible. Veuillez copier l'ID cloud manuellement.",
    "Copied!" : "Copié !",
    "Federated Cloud" : "Cloud Fédéré",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur {productName} ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son ID de Cloud Fédéré sur une instance fédérée dans la boîte de dialogue de partage. Cela ressemble à utilisateur@cloud.exemple.com.",
    "Your Federated Cloud ID" : "Votre ID de cloud fédéré",
    "Share it so your friends can share files with you:" : "Partagez-le afin que vos amis puissent partager des fichiers avec vous :",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via {productName}" : "Partager avec moi via {productName}",
    "HTML Code:" : "Code HTML :",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "Remote share" : "Partage distant",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} depuis {owner}@{remote} ?",
    "Remote share password" : "Mot de passe du partage distant",
    "Incoming share could not be processed" : "Le partage entrant n'a pas pu être traité",
    "Cloud ID copied to the clipboard" : "ID de Cloud Fédéré copié dans le presse-papiers",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son ID de Cloud Fédéré sur une instance fédérée dans la boîte de dialogue de partage. Cela ressemble à utilisateur@cloud.exemple.com.",
    "X (formerly Twitter)" : "X (anciennement Twitter)",
    "formerly Twitter" : "anciennement Twitter"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
